Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(125)

Unified Diff: dart/frog/presubmit.py

Issue 8497011: Parse formal parameters. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge
Patch Set: Rebased, frogsh, type warning Created 9 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « dart/frog/leg/typechecker.dart ('k') | dart/frog/tests/leg_only/leg_only.status » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: dart/frog/presubmit.py
diff --git a/dart/frog/presubmit.py b/dart/frog/presubmit.py
index c35792772d80361d51684bd54e20d100bfe2dd83..f9fc55d45c4bdb3384e753b331e4a468321534c3 100755
--- a/dart/frog/presubmit.py
+++ b/dart/frog/presubmit.py
@@ -51,15 +51,24 @@ def main(args):
"""Adds ANSI escape-code for bold-face"""
return "\033[1m%s\033[0m" % s
# VM Checked, produces checked
print 'Started'
start = time.time()
RunCommand('./frog.py',
'--vm_flags=--compile_all --enable_type_checks --enable_asserts',
'--', '--enable_type_checks', '--out=frogsh', 'frog.dart')
elapsed = time.time() - start
- print 'Compiling on Dart VM took %s seconds %s' % (b(elapsed),
- b('in checked mode'))
+ mode = 'in checked mode + compile all'
+ print 'Compiling on Dart VM took %s seconds %s' % (b(elapsed), b(mode))
+
+ # VM Checked, produces checked
+ start = time.time()
+ RunCommand('./frog.py',
+ '--vm_flags=--enable_type_checks --enable_asserts',
+ '--', '--enable_type_checks', '--out=frogsh', 'frog.dart')
+ elapsed = time.time() - start
+ mode = 'in checked mode'
+ print 'Compiling on Dart VM took %s seconds %s' % (b(elapsed), b(mode))
# VM Normal, produces checked
start = time.time()
« no previous file with comments | « dart/frog/leg/typechecker.dart ('k') | dart/frog/tests/leg_only/leg_only.status » ('j') | no next file with comments »
@@ -51,15 +51,24 @@ def main(args):
"""Adds ANSI escape-code for bold-face"""
return "\033[1m%s\033[0m" % s
- # VM Checked, produces checked
+ # VM Checked/CompileAll, produces checked
print 'Started'
start = time.time()

Powered by Google App Engine
This is Rietveld 408576698